# Bloqade

The python SDK for Bloqade.

## Installation

### Development Guide

If you want to setup locally for development, you can just cloning the repository and setup the
environment with [pdm](https://pdm.fming.dev/latest/).

```sh
pdm install
```
